Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(539)

Unified Diff: net/ssl/ssl_config.h

Issue 1135373002: Updated NetLog::ParametersCallback & all related calbacks returning value as scoped_ptr<base::Value… Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/ssl/openssl_ssl_util.cc ('k') | net/ssl/ssl_config.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/ssl/ssl_config.h
diff --git a/net/ssl/ssl_config.h b/net/ssl/ssl_config.h
index 0a195b0a20639ffc1bc1909dfdeab6b22848da72..3cb6198c79e01f9b7b4a561ee6295f1cf37117b6 100644
--- a/net/ssl/ssl_config.h
+++ b/net/ssl/ssl_config.h
@@ -115,10 +115,10 @@ struct NET_EXPORT SSLConfig {
// TLS extension is enabled.
bool signed_cert_timestamps_enabled;
- // require_forward_secrecy, if true, causes only (EC)DHE cipher suites to be
- // enabled. NOTE: this only applies to server sockets currently, although
- // that could be extended if needed.
- bool require_forward_secrecy;
+ // If true, causes only ECDHE cipher suites to be enabled. NOTE: This only
+ // applies to server sockets currently, although that could be extended if
+ // needed.
+ bool require_ecdhe;
// TODO(wtc): move the following members to a new SSLParams structure. They
// are not SSL configuration settings.
« no previous file with comments | « net/ssl/openssl_ssl_util.cc ('k') | net/ssl/ssl_config.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698